Documentation
¶
Overview ¶
Package ohmy pulls data from the ohmyrockness.com API
Index ¶
Constants ¶
const ( RegionNYC Region = 1 RegionChicago = 2 RegionLA = 3 RegionSXSW = 5 )
Variables ¶
var ( // NoCSRF is a generic error for any problem getting the CSRF token NoCSRF = errors.New("problem getting CSRF token") )
Functions ¶
This section is empty.
Types ¶
type Show ¶
type Show struct {
Bands []Band `json:"cached_bands"`
Venue Venue
Starts *time.Time `json:"starts_at"`
}
Show is a list of bands, a venue and some other info. Not everything returned in the API is included here.
Click to show internal directories.
Click to hide internal directories.